#######
History
#######

.. |dob| replace:: ``dob``
.. _dob: https://github.com/hotoffthehamster/dob

.. |dob-bright| replace:: ``dob-bright``
.. _dob-bright: https://github.com/hotoffthehamster/dob-bright

.. |dob-prompt| replace:: ``dob-prompt``
.. _dob-prompt: https://github.com/hotoffthehamster/dob-prompt

.. |dob-viewer| replace:: ``dob-viewer``
.. _dob-viewer: https://github.com/hotoffthehamster/dob-viewer

.. :changelog:

1.0.9 (2020-04-13)
==================

- API: New method to refresh "now".

1.0.8 (2020-04-12)
==================

- API: Pass Click context to post_processor handler.

1.0.7 (2020-04-09)
==================

- Bugfix: Allow Unicode characters in config values.

- Improve: Allow config to be reloaded, to support plugin config.

1.0.6 (2020-04-08)
==================

- Harden: Catch and report config file syntax error.

1.0.5 (2020-04-01)
==================

- Bugfix: Send package name to get_version, lest nark use its own.

1.0.4 (2020-04-01)
==================

- Refactor: DRY: Use new library get_version.

1.0.3 (2020-03-31)
==================

- UX: Fix help text indentation.

1.0.2 (2020-03-30)
==================

- DX: Process improvements.

1.0.0 (2020-03-30)
==================

- Booyeah: Inaugural release (spin-off from dob).

